@@ -1,3 +1,8 @@
+from torch.nn.parameter import Parameter
+import numpy as np
+import torch
+import torch.nn as nn
+
 class convert_for_training:
   def convert_train(self,om,trainfunc,data,params,factor):
     nm = copy.deepcopy(om)
@@ -11,7 +16,7 @@ class convert_for_training:
     nm = trainfunc(nm,data,params)
     return nm
 
-from torch.nn.parameter import Parameter
+
 class Gru2(nn.module):
 
   def forward(self, x, 
